@@ -1,13 +1,13 @@
+from .return_class import AbstractApiClass
 
 
-class ApplicationConnector():
+class ApplicationConnector(AbstractApiClass):
     """
         A connector to an external service
     """
 
     def __init__(self, client, applicationConnectorId=None, service=None, name=None, createdAt=None, status=None, auth=None):
-        self.client = client
-        self.id = applicationConnectorId
+        super().__init__(client, applicationConnectorId)
         self.application_connector_id = applicationConnectorId
         self.service = service
         self.name = name
@@ -18,9 +18,6 @@ class ApplicationConnector():
     def __repr__(self):
         return f"ApplicationConnector(application_connector_id={repr(self.application_connector_id)}, service={repr(self.service)}, name={repr(self.name)}, created_at={repr(self.created_at)}, status={repr(self.status)}, auth={repr(self.auth)})"
 
-    def __eq__(self, other):
-        return self.__class__ == other.__class__ and self.id == other.id
-
     def to_dict(self):
         return {'application_connector_id': self.application_connector_id, 'service': self.service, 'name': self.name, 'created_at': self.created_at, 'status': self.status, 'auth': self.auth}
 
