@@ -1,16 +1,16 @@
-from .refresh_schedule import RefreshSchedule
+from .return_class import AbstractApiClass
 from .dataset_version import DatasetVersion
+from .refresh_schedule import RefreshSchedule
 from .dataset_column import DatasetColumn
 
 
-class Dataset():
+class Dataset(AbstractApiClass):
     """
         A dataset reference
     """
 
     def __init__(self, client, datasetId=None, name=None, sourceType=None, dataSource=None, createdAt=None, ignoreBefore=None, ephemeral=None, lookbackDays=None, databaseConnectorId=None, databaseConnectorConfig=None, connectorType=None, featureGroupTableName=None, applicationConnectorId=None, applicationConnectorConfig=None, schema={}, refreshSchedules={}, latestDatasetVersion={}):
-        self.client = client
-        self.id = datasetId
+        super().__init__(client, datasetId)
         self.dataset_id = datasetId
         self.name = name
         self.source_type = sourceType
@@ -34,11 +34,8 @@ class Dataset():
     def __repr__(self):
         return f"Dataset(dataset_id={repr(self.dataset_id)}, name={repr(self.name)}, source_type={repr(self.source_type)}, data_source={repr(self.data_source)}, created_at={repr(self.created_at)}, ignore_before={repr(self.ignore_before)}, ephemeral={repr(self.ephemeral)}, lookback_days={repr(self.lookback_days)}, database_connector_id={repr(self.database_connector_id)}, database_connector_config={repr(self.database_connector_config)}, connector_type={repr(self.connector_type)}, feature_group_table_name={repr(self.feature_group_table_name)}, application_connector_id={repr(self.application_connector_id)}, application_connector_config={repr(self.application_connector_config)}, schema={repr(self.schema)}, refresh_schedules={repr(self.refresh_schedules)}, latest_dataset_version={repr(self.latest_dataset_version)})"
 
-    def __eq__(self, other):
-        return self.__class__ == other.__class__ and self.id == other.id
-
     def to_dict(self):
-        return {'dataset_id': self.dataset_id, 'name': self.name, 'source_type': self.source_type, 'data_source': self.data_source, 'created_at': self.created_at, 'ignore_before': self.ignore_before, 'ephemeral': self.ephemeral, 'lookback_days': self.lookback_days, 'database_connector_id': self.database_connector_id, 'database_connector_config': self.database_connector_config, 'connector_type': self.connector_type, 'feature_group_table_name': self.feature_group_table_name, 'application_connector_id': self.application_connector_id, 'application_connector_config': self.application_connector_config, 'schema': [elem.to_dict() for elem in self.schema or []], 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None, 'latest_dataset_version': [elem.to_dict() for elem in self.latest_dataset_version or []]}
+        return {'dataset_id': self.dataset_id, 'name': self.name, 'source_type': self.source_type, 'data_source': self.data_source, 'created_at': self.created_at, 'ignore_before': self.ignore_before, 'ephemeral': self.ephemeral, 'lookback_days': self.lookback_days, 'database_connector_id': self.database_connector_id, 'database_connector_config': self.database_connector_config, 'connector_type': self.connector_type, 'feature_group_table_name': self.feature_group_table_name, 'application_connector_id': self.application_connector_id, 'application_connector_config': self.application_connector_config, 'schema': self._get_attribute_as_dict(self.schema), 'refresh_schedules': self._get_attribute_as_dict(self.refresh_schedules), 'latest_dataset_version': self._get_attribute_as_dict(self.latest_dataset_version)}
 
     def create_version_from_file_connector(self, location=None, file_format=None, csv_delimiter=None):
         return self.client.create_dataset_version_from_file_connector(self.dataset_id, location, file_format, csv_delimiter)
@@ -97,3 +94,9 @@ class Dataset():
 
     def describe_feature_group(self):
         return self.client.describe_feature_group_by_table_name(self.feature_group_table_name)
+
+    def create_refresh_policy(self, cron: str):
+        return self.client.create_refresh_policy(self.name, cron, 'DATASET', dataset_ids=[self.id])
+
+    def list_refresh_policies(self):
+        return self.client.list_refresh_policies(dataset_ids=[self.id])
