@@ -1,13 +1,13 @@
+from .return_class import AbstractApiClass
 
 
-class FileConnector():
+class FileConnector(AbstractApiClass):
     """
         Verification result for an external storage service
     """
 
     def __init__(self, client, bucket=None, verified=None, writePermission=None):
-        self.client = client
-        self.id = None
+        super().__init__(client, None)
         self.bucket = bucket
         self.verified = verified
         self.write_permission = writePermission
@@ -15,8 +15,5 @@ class FileConnector():
     def __repr__(self):
         return f"FileConnector(bucket={repr(self.bucket)}, verified={repr(self.verified)}, write_permission={repr(self.write_permission)})"
 
-    def __eq__(self, other):
-        return self.__class__ == other.__class__ and self.id == other.id
-
     def to_dict(self):
         return {'bucket': self.bucket, 'verified': self.verified, 'write_permission': self.write_permission}
