@@ -1,13 +1,13 @@
+from .return_class import AbstractApiClass
 
 
-class UseCase():
+class UseCase(AbstractApiClass):
     """
         A Project Use Case
     """
 
     def __init__(self, client, useCase=None, prettyName=None, description=None):
-        self.client = client
-        self.id = None
+        super().__init__(client, None)
         self.use_case = useCase
         self.pretty_name = prettyName
         self.description = description
@@ -15,8 +15,5 @@ class UseCase():
     def __repr__(self):
         return f"UseCase(use_case={repr(self.use_case)}, pretty_name={repr(self.pretty_name)}, description={repr(self.description)})"
 
-    def __eq__(self, other):
-        return self.__class__ == other.__class__ and self.id == other.id
-
     def to_dict(self):
         return {'use_case': self.use_case, 'pretty_name': self.pretty_name, 'description': self.description}
